@@ -20,6 +20,6 @@ if __name__ == '__main__':
     from appzoo import App
 
     app = App()
-    app.add_route('/', predict, method="POST")
+    app.add_route('/xx', predict, method="POST")
 
     app.run(port=8000, access_log=True)
